@@ -164,8 +164,11 @@ class Topics:
     def get_main_category_var(var_name):
         """  GETTER HELPER  """
         try:
-            obj = MainCategories().__getattribute__(var_name)
-            return obj
+            cls = MainCategories()
+            if hasattr(cls, var_name):
+                obj = cls.__getattribute__(var_name)
+                return obj
+            return []
         except Exception as e:
             print(f"Failed to get attribute. e=[ {e} ]")
             return []
